Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2697)

Unified Diff: src/globals.h

Issue 2639883002: [turbofan] Add Receiver feedback for abstract/strict equality. (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/verifier.cc ('k') | src/interpreter/interpreter.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/globals.h
diff --git a/src/globals.h b/src/globals.h
index d0717ca19a10b62401c26205e085e9e71d7c66e9..ebb6f74050c99af6ac96ebd2ffa7220eaa038915 100644
--- a/src/globals.h
+++ b/src/globals.h
@@ -1247,8 +1247,9 @@ class BinaryOperationFeedback {
// Type feedback is encoded in such a way that, we can combine the feedback
// at different points by performing an 'OR' operation. Type feedback moves
// to a more generic type when we combine feedback.
// kSignedSmall -> kNumber -> kAny
// kInternalizedString -> kString -> kAny
// TODO(epertoso): consider unifying this with BinaryOperationFeedback.
class CompareOperationFeedback {
public:
@@ -1259,7 +1260,8 @@ class CompareOperationFeedback {
kNumberOrOddball = 0x7,
kInternalizedString = 0x8,
kString = 0x18,
- kAny = 0x3F
+ kReceiver = 0x20,
+ kAny = 0x7F
};
};
« no previous file with comments | « src/compiler/verifier.cc ('k') | src/interpreter/interpreter.cc » ('j') | no next file with comments »
@@ -1247,8 +1247,9 @@ class BinaryOperationFeedback {
// at different points by performing an 'OR' operation. Type feedback moves
// to a more generic type when we combine feedback.
-// kSignedSmall -> kNumber -> kAny
-// kInternalizedString -> kString -> kAny
+// kSignedSmall -> kNumber -> kAny
+// kInternalizedString -> kString -> kAny
+// kReceiver -> kAny
// TODO(epertoso): consider unifying this with BinaryOperationFeedback.
class CompareOperationFeedback {

Powered by Google App Engine
This is Rietveld 408576698